@@ -20,7 +20,7 @@
 
 #include "plugin.h"
 
-#include <QtQml>
+#include <QQmlEngine>
 
 #include "pulseaudio.h"
 #include "client.h"
